@@ -14,7 +14,7 @@ use Data::Table::Text qw(:all);
 use File::Copy;
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 
-our $VERSION = '2017.613';
+our $VERSION = '2017.615';
 
 #-------------------------------------------------------------------------------
 # Constants
@@ -183,7 +183,15 @@ sub sourceFolder
 
 sub appLibs                                                                     # Folder containing libraries to be copied into the app
  {my ($a) = @_;
-  $a->libs // $home.'../libs';
+
+  if (my $l = $a->libs)
+   {-d $l or confess "Cannot find libs folder:\n$l";
+    return $l
+   }
+
+  my $l = $home.'../libs';
+  return $l if -d $l;
+  undef
  }
 
 sub apkFileName                                                                 # Apk name - shorn of path
@@ -235,12 +243,13 @@ sub pushIcon
      {makePath($appIcon);
       my $s = $size;
       my $c = "convert -strip $icon -resize ${s}x${s}! $appIcon";
-      my $r = xxx($c, qr(convert));
+      my $r = xxx $c, qr(convert);
       !$r or confess "Unable to create icon:\n$r\n";
       my $res = $android->appResFolder;
       my $T = $res.$d.'-'.$dir.'dpi/'.$i.'.png';
       makePath($T);
-      print STDERR qx(rsync $appIcon $T);
+      my $R = qx(rsync -q $appIcon $T);
+      !$R or confess "Unable to create icon:\n$R\n";
      }
    }
  }
@@ -336,7 +345,7 @@ sub resources()
   my $t = << "END";
 <?xml version="1.0" encoding="utf-8"?>
 <resources>
-    <string name="package">$package</string>
+    <string name="packageName">$package</string>
     <string name="app_name">$title</string>
     <string name="versionName">$version</string>
     <string name="parameters">$parameters</string>
@@ -356,7 +365,7 @@ sub copySource
   my $P = $p =~ s/\./\//gr;
   my $t = $android->appSrcFolder."$P/";
   makePath($t);
-  print STDERR qx(rsync -r $s $t);                                              # Copy source files recursively
+  print STDERR qx(rsync -r $s $t), "\n";                                        # Copy source files recursively
   if (my $copy = $android->copyFiles)                                           # Do a copy file step to bring in additional files
    {$copy->($android, $t);
    }
@@ -368,9 +377,9 @@ sub copySource
 
 sub copyLibs
  {my ($android) = @_;
-  if (my $libSource = $android->libs)
-   {my $libTarget = $android->appLibs;
-    print STDERR qx(rsync -r $_ $libTarget) for glob("$libSource/*")
+  if (my $libSource = $android->appLibs)
+   {my $libTarget = $android->appLibsFolder;
+    print STDERR qx(rsync -r $libSource $libTarget), "\n";
    }
  }
 
@@ -504,8 +513,8 @@ sub make
     my $J = join ':', $androidJar, @libs;                                       # Jar files for javac
 
     my $r = xxx("javac -g -source  7 -target 7 -cp $J -d $classes $j");
+    $android->logMessage($r) if $r;
     $r !~ /error/ or confess "Java errors\n";
-    $android->logMessage($r);
    }
 
   if (1)                                                                        # Dx
@@ -583,6 +592,7 @@ sub install
   my $package    = $android->getPackage;
   my $activity   = $android->activity;
   my $adb        = $android->getAdb." -s $device";
+
   if (1)
    {my $c = "$adb install -r $apk";
     my $r = xxx($c);
